@@ -253,21 +253,21 @@ static struct hostent *parse_result(querybuf *answer,
 
 
 
-void dns_sethostent(int stayopen, void *opts)
+void dns_sethostent(int stayopen)
 {
     if (stayopen)
 	_res.options |= RES_STAYOPEN+RES_USEVC;
 }
 
 
-void dns_endhostent(void *opts)
+void dns_endhostent(void)
 {
     _res.options &= ~(RES_STAYOPEN+RES_USEVC);
     _res_close();
 }
 
 
-struct hostent *dns_gethostent(void *opts)
+struct hostent *dns_gethostent(void)
 {
     /* We can't do that... This would imply fetching information about
        all hosts on the whole internet. Hmm.. I suppose one could try to
@@ -279,7 +279,7 @@ struct hostent *dns_gethostent(void *opts)
 }
 
 
-struct hostent *dns_gethostbyname(const char *name, void *opts)
+struct hostent *dns_gethostbyname(const char *name)
 {
     int addr;
     int len;
@@ -290,7 +290,7 @@ struct hostent *dns_gethostbyname(const char *name, void *opts)
        it sanely in that case... */
     addr = inet_addr(name);
     if (addr != -1)
-	return dns_gethostbyaddr((char *) &addr, sizeof(addr), AF_INET, opts);
+	return dns_gethostbyaddr((char *) &addr, sizeof(addr), AF_INET);
 
     len = res_search(name, C_IN, T_A, qbuf.buf, sizeof(qbuf));
     if (len < 0)
@@ -301,8 +301,7 @@ struct hostent *dns_gethostbyname(const char *name, void *opts)
 
 
 struct hostent *dns_gethostbyaddr(const char *addr,
-				  int alen, int type,
-				  void *opts)
+				  int alen, int type)
 {
     querybuf qbuf;
     int len;
