@@ -29,13 +29,11 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void dns_setrpcent(int stayopen, void *opts);
-extern void dns_endrpcent(void *opts);
-extern struct rpcent *dns_getrpcent(void *opts);
-extern struct rpcent *dns_getrpcbyname(const char *name,
-				       void *opts);
-extern struct rpcent *dns_getrpcbynumber(int number,
-					 void *opts);
+extern void dns_setrpcent(int stayopen);
+extern void dns_endrpcent(void);
+extern struct rpcent *dns_getrpcent(void);
+extern struct rpcent *dns_getrpcbyname(const char *name);
+extern struct rpcent *dns_getrpcbynumber(int number);
 
 #endif
 
