@@ -29,10 +29,10 @@
 #include <sys/types.h>
 #include <grp.h>
 
-void nis_setgrent(void *opts);
-void nis_endgrent(void *opts);
-struct group *nis_getgrent(void *opts);
-struct group *nis_getgrgid(gid_t gid, void *opts);
-struct group *nis_getgrnam(const char *name, void *opts);
+void nis_setgrent(void);
+void nis_endgrent(void);
+struct group *nis_getgrent(void);
+struct group *nis_getgrgid(gid_t gid);
+struct group *nis_getgrnam(const char *name);
 
 #endif
