@@ -30,17 +30,17 @@
 #include "nis_services.h"
 
 
-void nis_setservent(int stayopen, void *opts)
+void nis_setservent(int stayopen)
 {
 }
 
 
-void nis_endservent(void *opts)
+void nis_endservent(void)
 {
 }
 
 
-struct servent *nis_getservent(void *opts)
+struct servent *nis_getservent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
@@ -48,8 +48,7 @@ struct servent *nis_getservent(void *opts)
 
 
 struct servent *nis_getservbyname(const char *name,
-				  const char *protocol,
-				  void *opts)
+				  const char *protocol)
 {
     errno = ECONNREFUSED;
     return NULL;
@@ -57,8 +56,7 @@ struct servent *nis_getservbyname(const char *name,
 
 
 struct servent *nis_getservbyport(int port,
-				  const char *protocol,
-				  void *opts)
+				  const char *protocol)
 {
     errno = ECONNREFUSED;
     return NULL;
