@@ -29,14 +29,12 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void nis_setservent(int stayopen, void *opts);
-extern void nis_endservent(void *opts);
-extern struct servent *nis_getservent(void *opts);
+extern void nis_setservent(int stayopen);
+extern void nis_endservent(void);
+extern struct servent *nis_getservent(void);
 extern struct servent *nis_getservbyname(const char *name,
-					 const char *protocol,
-					 void *opts);
+					 const char *protocol);
 extern struct servent *nis_getservbyport(int port,
-					 const char *protocol,
-					 void *opts);
+					 const char *protocol);
 
 #endif
