@@ -43,6 +43,6 @@ void _ENSWF(_setpwent)(void);
 void _ENSWF(_endpwent)(void);
 struct passwd * _ENSWF(_getpwent)(void);
 struct passwd * _ENSWF(_getpwuid)(uid_t uid);
-struct passwd * _ENSWF(_getpwnam)(char *name);
+struct passwd * _ENSWF(_getpwnam)(const char *name);
 
 #endif
