@@ -91,7 +91,7 @@ static struct protoent *protoent_parse(char *str, int len)
 
 
 
-void yp_setprotoent(int stayopen, void *opts)
+void yp_setprotoent(int stayopen)
 {
     rewind_flag = 1;
     if (savekey)
@@ -99,7 +99,7 @@ void yp_setprotoent(int stayopen, void *opts)
 }
 
 
-void yp_endprotoent(void *opts)
+void yp_endprotoent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -107,7 +107,7 @@ void yp_endprotoent(void *opts)
 }
 
 
-struct protoent *yp_getprotoent(void *opts)
+struct protoent *yp_getprotoent(void)
 {
     struct protoent *poe;
     char *map;
@@ -118,7 +118,7 @@ struct protoent *yp_getprotoent(void *opts)
     int keylen;
 
 
-    map = _ypopts_getmd(opts, "protocols", ".byname", &domain);
+    map = _ypopts_getmd("protocols", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -180,8 +180,7 @@ struct protoent *yp_getprotoent(void *opts)
 }
 
 
-struct protoent *yp_getprotobyname(const char *name,
-				   void *opts)
+struct protoent *yp_getprotobyname(const char *name)
 {
     struct protoent *pep;
     char *map;
@@ -190,7 +189,7 @@ struct protoent *yp_getprotobyname(const char *name,
     int len;
 
 
-    map = _ypopts_getmd(opts, "protocols", ".byname", &domain);
+    map = _ypopts_getmd("protocols", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -209,7 +208,7 @@ struct protoent *yp_getprotobyname(const char *name,
 }
 
 
-struct protoent *yp_getprotobynumber(int number, void *opts)
+struct protoent *yp_getprotobynumber(int number)
 {
     char buf[32];
     struct protoent *pep;
@@ -219,7 +218,7 @@ struct protoent *yp_getprotobynumber(int number, void *opts)
     int len;
 
 
-    map = _ypopts_getmd(opts, "protocols", ".bynumber", &domain);
+    map = _ypopts_getmd("protocols", ".bynumber", &domain);
     if (map == NULL)
 	return NULL;
 
