@@ -33,7 +33,7 @@ int main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    pw = nis_getpwnam(argv[1], NULL);
+    pw = nis_getpwnam(argv[1]);
 
     if (pw)
 	print_passwd(pw);
