@@ -36,7 +36,7 @@ main(int argc, char *argv[])
     struct group *gr;
 
 
-    gr = yp_getgrgid(atoi(argv[1]), NULL);
+    gr = yp_getgrgid(atoi(argv[1]));
 
     if (gr)
 	print_group(gr);
